==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/General/statusicon/translations/statusicon_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Настройки модуля Status Icon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>Всплывающая подсказка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>Задержка, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>Всплывающее сообщение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>Показывать полосу завершения</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>Разделить имя файла, если нет тегов</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation type="unfinished">32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Change template</source>
        <translation>Изменить шаблон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>Использовать стандартные иконки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Tooltip Template</source>
        <translation>Шаблон всплывающей подсказки</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="65"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="66"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="67"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="69"/>
        <source>Next</source>
        <translation>Следующий фрагмент</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="70"/>
        <source>Previous</source>
        <translation>Предыдущий фрагмент</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="125"/>
        <source>Now Playing</source>
        <translation>Сейчас играет</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Модуль Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>О модуле Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Модуль Status Icon для Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Writen by:</source>
        <translation>Разработчики:</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>StatusIconPopupWidget</name>
    <message>
        <location filename="../statusiconpopupwidget.cpp" line="135"/>
        <source>Stopped</source>
        <translation>Остановлено</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/General/statusicon/translations/statusicon_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Настройки модуля Status Icon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>Всплывающая подсказка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>Задержка, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>Всплывающее сообщение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>Показывать полосу завершения</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>Разделить имя файла, если нет тегов</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation type="unfinished">32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Change template</source>
        <translation>Изменить шаблон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>Использовать стандартные иконки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Tooltip Template</source>
        <translation>Шаблон всплывающей подсказки</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="65"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="66"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="67"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="69"/>
        <source>Next</source>
        <translation>Следующий фрагмент</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="70"/>
        <source>Previous</source>
        <translation>Предыдущий фрагмент</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="125"/>
        <source>Now Playing</source>
        <translation>Сейчас играет</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Модуль Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>О модуле Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Модуль Status Icon для Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Written by:</source>
        <translation>Разработчики:</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="54"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>StatusIconPopupWidget</name>
    <message>
        <location filename="../statusiconpopupwidget.cpp" line="135"/>
        <source>Stopped</source>
        <translation>Остановлено</translation>
    </message>
</context>
</TS>
